==> 1.5.1.tar.gz: example/lib/ui/activity_fragment.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart' hide DialogRoute;
import 'package:flutter/rendering.dart';
import 'package:flutterx_application/flutterx_application.dart';
import 'package:flutterx_live_data/flutterx_live_data.dart';
import 'package:flutterx_preferences/flutterx_preferences.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

class FragmentActivity extends StatelessWidget {
  static final ActivityRoute<void> route = ActivityRoute(
      title: (_) => 'Fragment', location: '/fragment', builder: (context, args) => const FragmentActivity._());

  const FragmentActivity._({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) => Scaffold(
      body: FragmentContainer(
          key: const FragmentContainerKey('container'),
          storage: sessionStorage,
          fragments: Colors.primaries.map((color) => Fragment1(color: color)).toList(growable: false)));
}

MutableLiveData<int> _shared = MutableLiveData(initialValue: 0);

class Fragment1 extends Fragment {
  final Color color;

  Fragment1({required this.color}) : super(key: FragmentKey('#${color.hexString}'));

  @override
  FragmentState createState() => Fragment1State();

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(ColorProperty('color', color));
  }
}

class Fragment1State extends FragmentState<Fragment1>
    with AutomaticKeepAliveClientMixin, StateObserver, FragmentStateObserver {
  int _buildCount = 0;

  @override
  bool get wantKeepAlive => true;

  @override
  void registerObservers() => _shared.observe(this, _onChanged);

  void _onChanged(int value) {
    if (mounted) setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    super.build(context);
    _buildCount++;
    return SingleChildScrollView(
        child: Container(
            color: widget.color,
            alignment: Alignment.center,
            child: Column(mainAxisSize: MainAxisSize.min, children: [
              const SizedBox(height: 24),
              Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                Text('Fragment ${widget.key} $_buildCount args: $args'),
                const SizedBox(width: 24),
                LiveDataBuilder<bool>(
                    data: manager.canGoBack,
                    builder: (context, enabled) => ElevatedButton(
                        style: ElevatedButton.styleFrom(
                            primary: Colors.white,
                            splashFactory: NoSplash.splashFactory,
                            onPrimary: Colors.black,
                            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                            shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                            side: const BorderSide()),
                        onPressed: enabled ? () => manager.back() : null,
                        child: const Text('Back'))),
                const SizedBox(width: 24),
                LiveDataBuilder<bool>(
                    data: manager.canGoForward,
                    builder: (context, enabled) => ElevatedButton(
                        style: ElevatedButton.styleFrom(
                            primary: Colors.white,
                            splashFactory: NoSplash.splashFactory,
                            onPrimary: Colors.black,
                            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                            shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                            side: const BorderSide()),
                        onPressed: enabled ? () => manager.forward() : null,
                        child: const Text('Forward'))),
                const SizedBox(width: 24),
                ElevatedButton(
                    style: ElevatedButton.styleFrom(
                        primary: Colors.white,
                        splashFactory: NoSplash.splashFactory,
                        onPrimary: Colors.black,
                        padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                        shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                        side: const BorderSide()),
                    onPressed: () => _shared.value++,
                    child: Text('COUNTER ${_shared.value}')),
              ]),
              ...Colors.primaries.map((color) => Padding(
                  padding: const EdgeInsets.all(12),
                  child: ElevatedButton(
                      style: ElevatedButton.styleFrom(
                          primary: color,
                          splashFactory: NoSplash.splashFactory,
                          onPrimary: color.computeLuminance() < .5 ? Colors.white : Colors.black,
                          padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                          shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                          side: BorderSide(color: color.computeLuminance() < .5 ? Colors.white : Colors.black)),
                      onPressed: () => manager.navigateToKey(FragmentKey('#${color.hexString}')),
                      child: Text('Go to #${color.hexString}')))),
            ])));
  }
}

==> 1.5.7.tar.gz: example/lib/ui/activity_fragment.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart' hide DialogRoute;
import 'package:flutter/rendering.dart';
import 'package:flutterx_application/flutterx_application.dart';
import 'package:flutterx_live_data/flutterx_live_data.dart';
import 'package:flutterx_preferences/flutterx_preferences.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

LiveList<Color> _colors = LiveList(source: [Colors.white, ...Colors.primaries]);

class FragmentActivity extends StatefulWidget {
  static final ActivityRoute<void> route = ActivityRoute(
      title: (_) => 'Fragment', location: '/fragment', builder: (context, args) => const FragmentActivity._());

  const FragmentActivity._({Key? key}) : super(key: key);

  @override
  State<FragmentActivity> createState() => _FragmentActivityState();
}

class _FragmentActivityState extends State<FragmentActivity> {
  // @override
  // void initState() {
  //   super.initState();
  //   Future.delayed(const Duration(seconds: 1), () async {
  //     for (final color in Colors.primaries) {
  //       _colors.add(color);
  //       await Future.delayed(const Duration(seconds: 5));
  //     }
  //   });
  // }

  @override
  Widget build(BuildContext context) => Scaffold(
      body: LiveDataBuilder<List<Color>>(
          data: _colors,
          builder: (context, colors) => FragmentContainer(
              key: const FragmentContainerKey('container'),
              storage: sessionStorage,
              fragments: colors.map((color) => Fragment1(color: color)).toList(growable: false))));
}

MutableLiveData<int> _shared = MutableLiveData(initialValue: 0);

class Fragment1 extends Fragment {
  final Color color;

  Fragment1({required this.color}) : super(key: FragmentKey('#${color.hexString}'));

  @override
  FragmentState createState() => Fragment1State();

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(ColorProperty('color', color));
  }
}

class Fragment1State extends FragmentState<Fragment1>
    with AutomaticKeepAliveClientMixin, StateObserver, FragmentStateObserver {
  int _buildCount = 0;

  @override
  bool get wantKeepAlive => true;

  @override
  void registerObservers() => _shared.observe(this, _onChanged);

  void _onChanged(int value) {
    if (mounted) setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    super.build(context);
    _buildCount++;
    return SingleChildScrollView(
        child: Container(
            color: widget.color,
            alignment: Alignment.center,
            child: Column(mainAxisSize: MainAxisSize.min, children: [
              const SizedBox(height: 24),
              Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                Text('Fragment ${widget.key} $_buildCount args: $args'),
                const SizedBox(width: 24),
                LiveDataBuilder<bool>(
                    data: manager.canGoBack,
                    builder: (context, enabled) => ElevatedButton(
                        style: ElevatedButton.styleFrom(
                            primary: Colors.white,
                            splashFactory: NoSplash.splashFactory,
                            onPrimary: Colors.black,
                            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                            shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                            side: const BorderSide()),
                        onPressed: enabled ? () => manager.back() : null,
                        child: const Text('Back'))),
                const SizedBox(width: 24),
                LiveDataBuilder<bool>(
                    data: manager.canGoForward,
                    builder: (context, enabled) => ElevatedButton(
                        style: ElevatedButton.styleFrom(
                            primary: Colors.white,
                            splashFactory: NoSplash.splashFactory,
                            onPrimary: Colors.black,
                            padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                            shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                            side: const BorderSide()),
                        onPressed: enabled ? () => manager.forward() : null,
                        child: const Text('Forward'))),
                const SizedBox(width: 24),
                ElevatedButton(
                    style: ElevatedButton.styleFrom(
                        primary: Colors.white,
                        splashFactory: NoSplash.splashFactory,
                        onPrimary: Colors.black,
                        padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                        shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
                        side: const BorderSide()),
                    onPressed: () => _shared.value++,
                    child: Text('COUNTER ${_shared.value}')),
              ]),
              LiveDataBuilder<List<Color>>(
                  data: _colors,
                  builder: (context, colors) => Column(
                      mainAxisSize: MainAxisSize.min,
                      children: colors
                          .map((color) => Padding(
                              padding: const EdgeInsets.all(12),
                              child: ElevatedButton(
                                  style: ElevatedButton.styleFrom(
                                      primary: color,
                                      splashFactory: NoSplash.splashFactory,
                                      onPrimary: color.computeLuminance() < .5 ? Colors.white : Colors.black,
                                      padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                                      shape: const RoundedRectangleBorder(
                                          borderRadius: BorderRadius.all(Radius.circular(12))),
                                      side: BorderSide(
                                          color: color.computeLuminance() < .5 ? Colors.white : Colors.black)),
                                  onPressed: () => manager.navigateToKey(FragmentKey('#${color.hexString}')),
                                  child: Text('Go to #${color.hexString}'))))
                          .toList(growable: false))),
            ])));
  }
}
